#!/bin/bash

wsd="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
output='/tmp'

# Download Freemius API wrapper in php
if [ ! -d "$wsd/freemius-php-api" ]; then
    echo "Download Freemius PHP SDK"
    git clone https://github.com/Freemius/php-sdk.git "$wsd"/freemius-php-api
fi
if [ ! -f "$wsd/config.ini" ]; then
    echo "file config.ini missing"
    exit
fi
echo "tree of wsd: $(tree L2 ${wsd})" 

# Read the config.ini
eval $(crudini --get --format=sh  "$wsd"/config.ini $1)
eval $(crudini --get --format=sh  "$wsd"/config.ini Login)

# David - added env variables to replace config.ini
# Call deploy with config.ini encoded 
# deploy.sh <config[selection] or ""> <pubkey> <secretkey> <id> <path> <filename> <release_mode> <user> <sandbox> <includes_free>
pubkey="$2"
secretkey="$3"
id="$4"
path="$5"
filename="$6"
release_mode="$7"
user="$8"
sandbox="$9"
plugin_type="$10"

echo "input vars $0 $1 $2 $3 $4 $5 $6 $7 $8 $9"
echo "vars pubkey ${pubkey} secretkey ${secretkey} id ${id} path ${path} filename ${filename} release_mode ${release_mode} user ${user} sandbox ${sandbox}"

if [ -z "$path" ]; then
    echo "- Missing Plugin path in $wsd/config.ini"
    exit
fi

echo "- Deploy process started"

. "$wsd"/package.sh $path $filename

filezip="$output"/"$packagename"-"$version".zip
echo "found zip of package to be updated on freemius: ${filezip}"

php "$wsd"/deploy.php "$user" "$pubkey" "$secretkey" "$filezip" "$id" "$sandbox" "$version" "$release_mode" "$plugin_type"
status=$?

if [ $status -ne 3 ]; then
    rm "$filezip"

    filezipfree="$output"/"$packagename"-"$version".free.zip

    . "$wsd"/release.sh $filezipfree
else
    echo "Error happened, file zip generated at $filezip"
fi
