import re
import sys

log_list = []
latest_version = False

if len(sys.argv) < 4:
    print("Usage: python update_changelog_and_readme.py <pwd> <folder> <post_version> <change_type>")
    sys.exit(1)

pwd = sys.argv[1]
folder = sys.argv[2]
post_version = sys.argv[3]
change_type = sys.argv[4]

# Return the text position in lines file
def find_text_pos(text, lines):
    for i, line in enumerate(lines):
        if line.strip() == text:
            pos = i
            return pos
    return None

# Open the changelog file in read mode
try:
    with open('changelog.txt', 'r') as changelog:
        # Read the contents of the file
        changelog_text = changelog.read()
except:
    print('An exception occurred')

new_log_pattern = r'\[((?:version|bug-fix|feature))\]\s*'
new_matches = re.findall(new_log_pattern, changelog_text)
print(new_matches)

# content = re.sub(rf'\[{change_type}\] ', f'[{change_type}] [version {post_version}] ', changelog_text, count=1)

# with open('changelog.txt', 'w') as f:
#     f.write(content)

# Define the regular expression pattern with capturing groups
pattern = r'\[((?:version|bug-fix|feature))\]\s+\[version\s+(\d+)\.(\d+)\.(\d+)\]((?:\n\s+- .*)*)'

# Find all non-overlapping matches of the pattern in the text
matches = re.findall(pattern, changelog_text)

# print(matches)

# Extract information from each match, convert it into the readme format and save it in the logs array
# It will just save the latest version logs, and then just the 'version' log in the prev versions
try:
    for match in matches:
        if match[0] == 'version' and not latest_version:
            latest_version = True
        if not latest_version or match[0] == 'version':
            version_type = match[0]
            version_number = f"{match[1]}.{match[2]}.{match[3]}"
            if match[4] != '':
                description = match[4].replace('-', '*').replace('\n    ', '\n').strip()
                log_list.append(f"\n= {version_number} =\n* {version_type}\n{description}")
            else:
                log_list.append(f"\n= {version_number} =\n* {version_type}")
except:
    print('An exception occurred')

#  Open the readme file in read mode and save the lines

try:
    with open('readme.txt', 'r') as readme:
        lines = readme.readlines()
except:
    print('An exception occurred')

changelog_pos = None
upgrade_notice_pos = None

# Find the Changelog and Upgrade Notice position
changelog_pos = find_text_pos('== Changelog ==', lines)
upgrade_notice_pos = find_text_pos('== Upgrade Notice ==', lines)

# Delete the information between Changelog and Upgrade Notice
if changelog_pos and upgrade_notice_pos :
    del lines[changelog_pos+1:upgrade_notice_pos]

# Write the log information between Changelog and Upgrade Notice lines
if changelog_pos:
    for log in log_list:
        new_log = f"{log}\n"
        lines.insert(changelog_pos+1, new_log)
        changelog_pos += 1

    lines.insert(changelog_pos+1, '\n')
    changelog_pos += 1

    upgrade_notice_pos = find_text_pos('== Upgrade Notice ==', lines)

    # Update the "upgrade notice" to the latest log
    if upgrade_notice_pos:
        del lines[upgrade_notice_pos+1:]
        lines.insert(upgrade_notice_pos+1, f"{log_list[0]}\n")


# Write the lines into the readme file
try:
    with open('readme.txt', 'w') as readme:
        readme.writelines(lines)
except:
    print('An exception occurred')
