#!/usr/bin/env python3
import re
import sys
import os
from collections import defaultdict


if len(sys.argv) < 3:
    print("Usage: python update_changelog_and_readme.py <folder> <new_version>")
    sys.exit(1)

folder = sys.argv[1]
new_version = sys.argv[2]
change_type = sys.argv[3]

changelog_file = os.path.join(folder, 'changelog.txt')
readme_file = os.path.join(folder, 'readme.txt')

# Update the changelog with the new version number
with open(changelog_file, 'r') as f:
    content = f.read()

content = re.sub(r'\[{update_type}\] ', f'[{change_type}] [version {new_version}] ', content, count=1)

with open(changelog_file, 'w') as f:
    f.write(content)

# Create a database of versions, features, and bugfixes with their respective bullet points
entry_types = ['version', 'feature', 'bug-fix']
entry_database = defaultdict(list)

with open(changelog_file, 'r') as f:
    content = f.read()

for entry_type in entry_types:
    pattern = rf'\[{entry_type}\] \[version [0-9]+\.[0-9]+\.[0-9]+\][^\[]*'
    matches = re.findall(pattern, content, re.MULTILINE)
    
    for match in matches:
        version = re.search(r'\[version ([0-9]+\.[0-9]+\.[0-9]+)\]', match).group(1)
        entry_database[entry_type].append((version, match))

# Generate the changelog using the database
def get_recent_entries(entry_type, count=2):
    return "\n".join(entry[1] for entry in entry_database[entry_type][-count:])

recent_bug_fixes = get_recent_entries('bug-fix')
recent_features = get_recent_entries('feature')
recent_versions = get_recent_entries('version')

changelog_output = f"== Changelog ==\n{recent_bug_fixes}\n{recent_features}\n{recent_versions}"

with open(readme_file, 'r') as f:
    content = f.read()

content = re.sub(r'== Changelog ==[^\[]*', changelog_output, content, flags=re.MULTILINE)

with open(readme_file, 'w') as f:
    f.write(content)