#!/usr/bin/env python3
import re
import sys
import os
from collections import defaultdict


if len(sys.argv) < 3:
    print("Usage: python update_changelog_and_readme.py <folder> <new_version>")
    sys.exit(1)

folder = sys.argv[1]
new_version = sys.argv[2]
change_type = sys.argv[3]
post_version = sys.argv[4]

changelog_file = os.path.join(folder, 'changelog.txt')

readme_file = os.path.join(folder, 'readme.txt')

# Update the changelog with the new version number
with open(changelog_file, 'r') as f:
    content = f.read()

content = re.sub(r'\[{update_type}\] ', f'[{change_type}] [version {new_version}] ', content, count=1)

with open(changelog_file, 'w') as f:
    f.write(content)

# Read the changelog content
with open(changelog_file, 'r') as f:
    changelog_content = f.read()

# Find the most recent entry
pattern = r'(\[' + re.escape(change_type) + r'\] \[version ' + re.escape(post_version) + r'\].*?)(?=\[\w+-\w+\]|$)'
most_recent_entry = re.search(pattern, changelog_content, re.DOTALL)
if most_recent_entry:
    most_recent_entry = most_recent_entry.group(1)
else:
    print("Error: Could not find the most recent entry.")
    sys.exit(1)

# Update the README file
with open(readme_file, 'r') as f:
    readme_content = f.read()

readme_updated = re.sub(r'(== Changelog ==)', r'\1\n' + most_recent_entry, readme_content, flags=re.MULTILINE)

with open(readme_file, 'w') as f:
    f.write(readme_updated)