#!/usr/bin/env python3
import re
import sys
import os
from collections import defaultdict


if len(sys.argv) < 3:
    print("Usage: python update_changelog_and_readme.py <folder> <new_version>")
    sys.exit(1)

folder = sys.argv[1]
new_version = sys.argv[2]
change_type = sys.argv[3]

changelog_file = os.path.join(folder, 'changelog.txt')

readme_file = os.path.join(folder, 'readme.txt')

# Update the changelog with the new version number
with open(changelog_file, 'r') as f:
    content = f.read()

content = re.sub(r'\[{update_type}\] ', f'[{change_type}] [version {new_version}] ', content, count=1)

with open(changelog_file, 'w') as f:
    f.write(content)

# Extract all entries
with open(changelog_file, 'r') as f:
    changelog_content = f.read()

bug_fix_pattern = r'\[bug-fix\] \[version ([\d.]+)\]\s*(.*?)\s*(?=\[|$)'
feature_pattern = r'\[feature\] \[ version ([\d.]+)\]\s*(.*?)\s*(?=\[|$)'
version_pattern = r'\[version\] \[version ([\d.]+)\]\s*(.*?)\s*(?=\[|$)'

bug_fixes = re.findall(bug_fix_pattern, changelog_content, re.DOTALL)
features = re.findall(feature_pattern, changelog_content, re.DOTALL)
versions = re.findall(version_pattern, changelog_content, re.DOTALL)

# Sort entries semantically
def semantic_sort(entries):
    return sorted(entries, key=lambda x: tuple(map(int, x[0].split('.'))), reverse=True)

bug_fixes = semantic_sort(bug_fixes)
features = semantic_sort(features)
versions = semantic_sort(versions)

# Suppress bug-fixes that come before a feature
def suppress_bug_fixes_before_feature(bug_fixes, features):
    if not features:
        return bug_fixes

    latest_feature_version = features[0][0]
    return [bug_fix for bug_fix in bug_fixes if bug_fix[0] > latest_feature_version]

bug_fixes = suppress_bug_fixes_before_feature(bug_fixes, features)

# Display the sorted and filtered changelog
output = []

for version, version_content in versions:
    output.append(f'[version] [version {version}]')
    output.append(version_content.strip())

    for feature_version, feature_content in features:
        if feature_version <= version:
            output.append(f'[feature] [ version {feature_version}]')
            output.append(feature_content.strip())
            features.remove((feature_version, feature_content))

    for bug_fix_version, bug_fix_content in bug_fixes:
        if bug_fix_version <= version:
            output.append(f'[bug-fix] [version {bug_fix_version}]')
            output.append(bug_fix_content.strip())
            bug_fixes.remove((bug_fix_version, bug_fix_content))

print("\n\n".join(output))




changelog_output = "==" + " Changelog ==\n" + '\n\n'.join(output)

with open(readme_file, 'r') as f:
    content = f.read()

content = re.sub(r'== Changelog ==[^\[]*', changelog_output, content, flags=re.MULTILINE)

with open(readme_file, 'w') as f:
    f.write(content)